<?php

/**
 * Plugin Name: NicnatDirect Shipping
 * Plugin URI: https://nicnat.com/
 * Description: Fastest and cheapest air shipping rates across the world, starting as low as $19.99.
 * Version: 1.0
 * Author: NicnatDirect
 * Author URI: https://nicnat.com/
 * License: GPL2
 */

if (!defined('ABSPATH')) exit;

// Enqueue CSS
function nicnat_enqueue_plugin_styles()
{
    wp_enqueue_style('nicnat-select2-style', plugin_dir_url(__FILE__) . 'assets/css/select2.min.css', [], '1.0.0');
    wp_enqueue_style('dataTables-jquery', plugin_dir_url(__FILE__) . 'assets/css/jquery.dataTables.min.css', [], '1.0.0');
    wp_enqueue_style('nicnat-style', plugin_dir_url(__FILE__) . 'assets/css/style.css', [], '1.0.0');
}
add_action('admin_enqueue_scripts', 'nicnat_enqueue_plugin_styles');


function check_user_access()
{
    $domain = get_site_url();

    $response = wp_remote_post('https://nicnatdirect.com/global/api/user_access.php', [
        'method'  => 'POST',
        'headers' => ['Content-Type' => 'application/json'],
        'body'    => json_encode(['domain_name' => $domain]),
        'timeout' => 10,
    ]);

    if (is_wp_error($response)) {
        return ['access' => false, 'reason' => 'Connection error'];
    }

    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);

    if (isset($data['success']) && $data['success'] === true) {
        if ($data['status'] == 1) {
            return ['access' => true];
        } elseif ($data['status'] == 2) {
            $reason = isset($data['reason']) ? $data['reason'] : 'Access denied by server.';
            return ['access' => false, 'reason' => $reason];
        }
    }

    return ['access' => false, 'reason' => 'Invalid response or no access'];
}

$access_data = check_user_access();
if ($access_data['access']) {



    // Check access for partial plugin features
    function check_plugin_access()
    {
        $domain = site_url();

        $response = wp_remote_post('https://nicnatdirect.com/global/api/pulgin_access.php', [
            'method'  => 'POST',
            'headers' => ['Content-Type' => 'application/json'],
            'body'    => json_encode(['domain_name' => $domain]),
            'timeout' => 10,
        ]);

        if (is_wp_error($response) || wp_remote_retrieve_response_code($response) !== 200) {
            return false;
        }

        $body = json_decode(wp_remote_retrieve_body($response), true);

        return isset($body['success']) && $body['success'] && isset($body['data']['status']) && $body['data']['status'] == 1;
    }





    // Step 1: Initialize shipping method
    add_action('woocommerce_shipping_init', 'wsef_shipping_method_init');

    function wsef_shipping_method_init()
    {

        if (!check_plugin_access()) {
            return; // Block loading shipping method
        }

        if (!class_exists('WSEF_Dynamic_Shipping_Method')) {
            class WSEF_Dynamic_Shipping_Method extends WC_Shipping_Method
            {

                public function __construct()
                {
                    $this->id = 'wsef_dynamic_shipping';
                    $this->method_title = __('NicnatDirect Shipping', 'woocommerce');
                    $this->method_description = __('Fetch shipping rate from external API based on product weight and destination country.', 'woocommerce');
                    $this->title = __('NicnatDirect Shipping', 'woocommerce');
                    $this->enabled = "yes";
                    $this->init();
                }

                public function init()
                {
                    $this->init_form_fields();
                    $this->init_settings();

                    $this->enabled = $this->get_option('enabled', 'yes');

                    add_action('woocommerce_update_options_shipping_' . $this->id, [$this, 'process_admin_options']);
                }

                public function init_form_fields()
                {
                    $this->form_fields = [
                        'enabled' => [
                            'title' => __('Enable/Disable', 'woocommerce'),
                            'type'  => 'checkbox',
                            'label' => __('Enable this shipping method', 'woocommerce'),
                            'default' => 'yes',
                        ],
                    ];

                    $shipping_options = $this->get_external_shipping_methods();

                    if (!empty($shipping_options)) {
                        foreach ($shipping_options as $key => $data) {
                            $this->form_fields['checkbox_' . $key] = [
                                'title' => '',
                                'type' => 'checkbox',
                                'label' => $data['label'],
                                'default' => 'yes',
                            ];
                        }
                    }
                }



                private function get_external_shipping_methods()
                {
                    $response = wp_remote_post('https://nicnatdirect.com/global/api/get-shipping-methods.php', [
                        'method'  => 'POST',
                        'headers' => ['Content-Type' => 'application/json'],
                        'body'    => json_encode([]),
                        'timeout' => 10,
                    ]);

                    $options = [];

                    if (!is_wp_error($response) && wp_remote_retrieve_response_code($response) === 200) {
                        $body = wp_remote_retrieve_body($response);
                        $methods = json_decode($body, true);

                        if (!empty($methods) && is_array($methods)) {
                            foreach ($methods as $method) {
                                if (isset($method['id'], $method['unique_id'], $method['shipping_method_name'])) {
                                    $options[$method['unique_id']] = [
                                        'id' => $method['id'],
                                        'label' => $method['shipping_method_name']
                                    ];
                                }
                            }
                        }
                    }

                    return $options;
                }




                // Convert weight to lbs
                private function convert_to_lbs($weight, $unit)
                {
                    switch ($unit) {
                        case 'g':
                            return $weight / 453.592;
                        case 'kg':
                            return $weight * 2.20462;
                        case 'oz':
                            return $weight / 16;
                        case 'lbs':
                        default:
                            return $weight;
                    }
                }

                // Convert dimensions to inches
                private function convert_to_inches($value, $unit)
                {
                    switch ($unit) {
                        case 'mm':
                            return $value / 25.4;
                        case 'cm':
                            return $value / 2.54;
                        case 'm':
                            return $value * 39.3701;
                        case 'in':
                        default:
                            return $value;
                    }
                }



                public function calculate_shipping($package = [])
                {
                    $country_code = WC()->customer->get_shipping_country();
                    error_log("country_code " . $country_code);

                    $country_id = $this->get_country_id_from_api($country_code);
                    if (!$country_id) {
                        wc_add_notice(__('We couldn’t fetch shipping options for your address. Please try again or contact support.'), 'error');
                        return;
                    }

                    $enabled_methods = [];
                    $methods = $this->get_external_shipping_methods();
                    foreach ($methods as $key => $data) {
                        if ($this->get_option('checkbox_' . $key) === 'yes') {
                            $enabled_methods[] = [
                                'id' => $data['id'],
                                'label' => $data['label']
                            ];
                        }
                    }

                    if (empty($enabled_methods)) return;

                    $weight_unit = get_option('woocommerce_weight_unit');
                    $dimension_unit = get_option('woocommerce_dimension_unit');

                    foreach ($enabled_methods as $method) {
                        $shipping_id = $method['id'];
                        $shipping_label = $method['label'];

                        $base_country = explode(':', get_option('woocommerce_default_country'))[0];
                        $shipping_country = $package['destination']['country'] ?? '';

                        $direction = 0;
                        if ($base_country && $shipping_country && strtoupper($base_country) !== strtoupper($shipping_country)) {
                            $direction = strtoupper($base_country) === 'US' ? 1 : (strtoupper($shipping_country) === 'US' ? 2 : 2);
                        }

                        $rates = $this->get_markup_and_divide_rate($country_id, $shipping_id, $direction);
                        if (isset($rates['error'])) {
                            wc_add_notice(__('Shipping methods currently not available for the selected country. Please choose a different shipping destination.'), 'error');
                            return;
                        }

                        if (empty($rates['markup_rate']) || empty($rates['divide_rate'])) continue;

                        $markup_rate = floatval($rates['markup_rate']);
                        $divide_rate = floatval($rates['divide_rate']);
                        if ($divide_rate <= 0) continue;

                        $cart_items = $package['contents'];
                        $products_info = [];
                        foreach ($cart_items as $values) {
                            $product = $values['data'];
                            $qty = $values['quantity'];

                            $weight = floatval($product->get_weight());
                            $width = floatval($product->get_width());
                            $length = floatval($product->get_length());
                            $height = floatval($product->get_height());

                            if ($weight <= 0 || $width <= 0 || $length <= 0 || $height <= 0) {
                                wc_add_notice(sprintf(
                                    "Product <strong>%s</strong> has missing or invalid dimensions or weight. Please contact support or update product details.",
                                    $product->get_name()
                                ), 'error');
                                return;
                            }

                            $weight_lbs = $this->convert_to_lbs($weight, $weight_unit);
                            $length_in = $this->convert_to_inches($length, $dimension_unit);
                            $width_in = $this->convert_to_inches($width, $dimension_unit);
                            $height_in = $this->convert_to_inches($height, $dimension_unit);

                            $dim_weight = ($length_in * $width_in * $height_in) / $divide_rate;

                            $products_info[] = [
                                'id' => $product->get_id(),
                                'qty' => $qty,
                                'weight_lbs' => $weight_lbs,
                                'dim_weight' => $dim_weight
                            ];
                        }

                        // NEW CHARGEABLE WEIGHT LOGIC
                        $chargeable_weight = 0;

                        if (count($products_info) == 1) {
                            $p = $products_info[0];
                            $dim_weight = $p['dim_weight'];
                            $actual = $p['weight_lbs'];
                            $qty = $p['qty'];

                            $max_weight = max($dim_weight, $actual);
                            $min_weight = min($dim_weight, $actual);

                            error_log("Single product dim_weight: $dim_weight, actual: $actual, qty: $qty, max_weight: $max_weight, min_weight: $min_weight");

                            if ($qty == 1) {
                                $chargeable_weight = ceil($max_weight);
                            } elseif ($qty == 2) {
                                $chargeable_weight = ceil($max_weight * 2);
                            } else {
                                $remaining_items = $qty - 1;
                                $chargeable_weight = ceil(($max_weight * 2) + ($actual * $remaining_items));
                            }

                            error_log("Chargeable Weight: $chargeable_weight");


                            $debug_data[] = [
                                'qty' => $qty,
                                'weight_lbs' => round($weight_lbs, 2),
                                'width_in' => round($width_in, 2),
                                'length_in' => round($length_in, 2),
                                'height_in' => round($height_in, 2),
                                'dim_weight' => round($dim_weight, 2),
                                'chargeable_weight' => round($chargeable_weight, 2),
                            ];
                        } else {
                            $max_weight = 0;
                            $max_product_index = 0;

                            foreach ($products_info as $index => $p) {
                                $dim_weight = $p['dim_weight'];
                                $actual = $p['weight_lbs'];
                                $max_for_product = max($dim_weight, $actual);

                                if ($max_for_product > $max_weight) {
                                    $max_weight = $max_for_product;
                                    $max_product_index = $index;
                                }
                            }

                            error_log("Multiple products max_weight: $max_weight at index: $max_product_index");

                            $other_weight = 0;
                            foreach ($products_info as $index => $p) {
                                $qty = $p['qty'];
                                $actual = $p['weight_lbs'];

                                error_log("Product $index - qty: $qty, actual: $actual");

                                if ($index == $max_product_index) {
                                    if ($qty > 1) {
                                        $weight_add = ($qty - 1) * $actual;
                                        $other_weight += $weight_add;
                                        error_log("Max product extra weight: $weight_add");
                                    }
                                } else {
                                    $weight_add = $qty * $actual;
                                    $other_weight += $weight_add;
                                    error_log("Other product weight added: $weight_add");
                                }
                            }

                            $chargeable_weight = ceil($max_weight + ($max_weight + $other_weight));
                            error_log("Chargeable Weight: $chargeable_weight");


                            $debug_data[] = [
                                'qty' => $qty,
                                'weight_lbs' => round($weight_lbs, 2),
                                'width_in' => round($width_in, 2),
                                'length_in' => round($length_in, 2),
                                'height_in' => round($height_in, 2),
                                'dim_weight' => round($dim_weight, 2),
                                'chargeable_weight' => round($chargeable_weight, 2),
                            ];
                        }



                        //	print_r($debug_data);

                        //echo('<script>console.log("Final Chargeable Weight: ' . $chargeable_weight.'");</script>');
                        error_log("weight_lbs: " . $weight_lbs);
                        error_log("length_in: " . $length_in);
                        error_log("width_in: " . $width_in);
                        error_log("height_in: " . $height_in);

                        error_log("Final Chargeable Weight: " . $chargeable_weight);

                        // Apply Rate
                        $item_rate = 0;
                        if ($chargeable_weight < 100 && !empty($rates['all_rates'])) {
                            foreach ($rates['all_rates'] as $rate) {
                                if (round($rate['weight']) == round($chargeable_weight)) {
                                    $rate_per_lbs = floatval($rate['shipping_rate']);
                                    $item_rate = $rate_per_lbs + round($rate_per_lbs * ($markup_rate / 100), 2);
                                    break;
                                }
                            }

                            if ($item_rate <= 0) {
                                wc_add_notice(sprintf(
                                    "Shipping rate not defined for chargeable weight <strong>%.2f lbs</strong>.",
                                    $chargeable_weight
                                ), 'error');
                                return;
                            }

                            error_log("item_rate: " . $item_rate);
                            $item_rate = ceil($item_rate) - 0.01;
                            error_log("Final item_rate: " . $item_rate);
                        } elseif (!empty($rates['freight_rates'])) {
                            foreach ($rates['freight_rates'] as $rate) {
                                if ($chargeable_weight >= $rate['min_weight'] && $chargeable_weight <= $rate['max_weight']) {
                                    $rate_per_lbs = floatval($rate['shipping_rate']);
                                    $item_rate = $rate_per_lbs + round($rate_per_lbs * ($markup_rate / 100), 2);
                                    break;
                                }
                            }

                            if ($item_rate <= 0) {
                                wc_add_notice(sprintf(
                                    "Freight rate not defined for chargeable weight <strong>%.2f lbs</strong>.",
                                    $chargeable_weight
                                ), 'error');
                                return;
                            }


                            error_log("markup_rate: " . $markup_rate);
                            error_log("item_rate: " . $item_rate);
                            $item_rate = ceil($item_rate * $chargeable_weight) - 0.01;
                            error_log("Final item_rate: " . $item_rate);
                        }



                        // print_r($rates['freight_rates']);


                        // Register shipping rate with WooCommerce
                        $rate = [
                            'id'    => $this->id . ':' . $shipping_id,
                            'label' => $shipping_label,
                            'cost'  => $item_rate,
                            'calc_tax' => 'per_order',
                        ];
                        $this->add_rate($rate);
                    }
                }


                // POST to get country ID from country code
                private function get_country_id_from_api($country_code)
                {
                    $response = wp_remote_post('https://nicnatdirect.com/global/api/post_country.php', [
                        'method' => 'POST',
                        'headers' => ['Content-Type' => 'application/json'],
                        'body' => json_encode(['country_code' => $country_code]),
                        'timeout' => 10,
                    ]);

                    if (is_wp_error($response)) return false;

                    $body = json_decode(wp_remote_retrieve_body($response), true);
                    return isset($body['country_id']) ? $body['country_id'] : false;
                }

                // POST to get markup and divide rate using country ID
                private function get_markup_and_divide_rate($country_id, $shipping_id, $direction)
                {

                    //error_log("shipping_id" . $shipping_id);


                    $response = wp_remote_post('https://nicnatdirect.com/global/api/post_markup.php', [
                        'method' => 'POST',
                        'headers' => ['Content-Type' => 'application/json'],
                        'body' => json_encode([
                            'country_id' => $country_id,
                            'shipping_id' => intval($shipping_id),
                            'direction' => $direction
                        ]),
                        'timeout' => 10,
                    ]);

                    if (is_wp_error($response)) return false;

                    return json_decode(wp_remote_retrieve_body($response), true);
                }
            }
        }
    }

    // Step 2: Register shipping method
    add_filter('woocommerce_shipping_methods', 'wsef_register_shipping_method');
    function wsef_register_shipping_method($methods)
    {
        $methods['wsef_dynamic_shipping'] = 'WSEF_Dynamic_Shipping_Method';
        return $methods;
    }




    // Add Settings link in Installed Plugins page
    function nicnatdirect_plugin_action_links($links)
    {
        $settings_link = '<a href="admin.php?page=nicnatdirect">Settings</a>';
        array_unshift($links, $settings_link);
        return $links;
    }
    add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'nicnatdirect_plugin_action_links');











































    // ===============================================================================================================
    // =============================================== Order Placed ==================================================
    // ===============================================================================================================


    add_action('woocommerce_thankyou', 'send_order_to_external_api', 10, 1);

    function send_order_to_external_api($order_id)
    {
        if (!$order_id) return;

        $order = wc_get_order($order_id);

        // Prepare order data
        $order_data = [
            'domain'        => get_site_url(),
            'order_id'      => $order->get_id(),
            'order_status'  => $order->get_status(),
            'total'         => $order->get_total(),

            'discount_total'  => $order->get_discount_total(),
            'shipping_total'  => $order->get_shipping_total(),
            'tax_total'       => $order->get_total_tax(),
            'shipping_method' => $order->get_shipping_method(),

            'payment_method'  => $order->get_payment_method(),
            'customer'      => [
                'first_name' => $order->get_shipping_first_name(),
                'last_name'  => $order->get_shipping_last_name(),
                'email'      => $order->get_billing_email(),
                'phone'      => $order->get_billing_phone(),
                'address'    => $order->get_shipping_address_1(),
                'city'       => $order->get_shipping_city(),
                'state'      => $order->get_shipping_state(),
                'postcode'   => $order->get_shipping_postcode(),
                'country'    => $order->get_shipping_country(),
            ],
            'products' => [],
        ];

        foreach ($order->get_items() as $item_id => $item) {
            $product = $item->get_product();

            $order_data['products'][] = [
                'product_id'   => $product->get_id(),
                'name'         => $item->get_name(),
                'quantity'     => $item->get_quantity(),
                'total'        => $item->get_total(),
                'sku'          => $product->get_sku(),
                'weight'       => $product->get_weight(),
                'dimensions'   => [
                    'width'  => $product->get_width(),
                    'height' => $product->get_height(),
                    'length' => $product->get_length(),
                ],
            ];
        }

        // API endpoint URL
        $api_url = 'https://nicnatdirect.com/global/api/order_products.php';

        // Send using wp_remote_post
        $response = wp_remote_post($api_url, [
            'method'    => 'POST',
            'headers'   => [
                'Content-Type' => 'application/json',
            ],
            'body'      => json_encode($order_data),
            'timeout'   => 30,
        ]);

        if (is_wp_error($response)) {
            error_log('API Error: ' . $response->get_error_message());
        } else {
            error_log('Order sent to external API. Response: ' . wp_remote_retrieve_body($response));
        }
    }






    // ===============================================================================================================
    // =============================================== Order Placed ==================================================
    // ===============================================================================================================










    // ===============================================================================================================
    // ========================================= order status changed ================================================
    // ===============================================================================================================


    add_action('woocommerce_order_status_changed', 'send_order_update_to_external_api', 10, 4);

    function send_order_update_to_external_api($order_id, $old_status, $new_status, $order)
    {
        if (!$order_id) return;

        // Prepare updated order data (same format as before)
        $order_data = [
            'domain'        => get_site_url(),
            'order_id'      => $order->get_id(),
            'order_status'  => $order->get_status(),
            'total'         => $order->get_total(),
            'payment_method' => $order->get_payment_method(),
            'customer'      => [
                'first_name' => $order->get_billing_first_name(),
                'last_name'  => $order->get_billing_last_name(),
                'email'      => $order->get_billing_email(),
                'phone'      => $order->get_billing_phone(),
                'address'    => $order->get_billing_address_1(),
                'city'       => $order->get_billing_city(),
                'state'      => $order->get_billing_state(),
                'postcode'   => $order->get_billing_postcode(),
                'country'    => $order->get_billing_country(),
            ],
            'products' => [],
        ];

        foreach ($order->get_items() as $item_id => $item) {
            $product = $item->get_product();

            $order_data['products'][] = [
                'product_id'   => $product->get_id(),
                'name'         => $item->get_name(),
                'quantity'     => $item->get_quantity(),
                'total'        => $item->get_total(),
                'sku'          => $product->get_sku(),
                'weight'       => $product->get_weight(),
                'dimensions'   => [
                    'width'  => $product->get_width(),
                    'height' => $product->get_height(),
                    'length' => $product->get_length(),
                ],
            ];
        }

        // API endpoint
        $api_url = 'https://nicnatdirect.com/global/api/order_products.php'; // or a new endpoint for updates

        $response = wp_remote_post($api_url, [
            'method'    => 'POST',
            'headers'   => ['Content-Type' => 'application/json'],
            'body'      => json_encode($order_data),
            'timeout'   => 30,
        ]);

        if (is_wp_error($response)) {
            error_log('Order update API Error: ' . $response->get_error_message());
        } else {
            error_log('Order update sent to external API. Response: ' . wp_remote_retrieve_body($response));
        }
    }

    // ===============================================================================================================
    // ========================================= order status changed ================================================
    // ===============================================================================================================








































    // ===============================================================================================================
    // ================================== WordPress Admin Panel Sidebar Menu =========================================
    // ===============================================================================================================

    add_action('admin_menu', 'nicnatdirect_admin_menu');

    function nicnatdirect_admin_menu()
    {
        add_menu_page(
            'NicnatDirect',                // Page title
            'NicnatDirect',                // Menu title
            'manage_options',            // Capability
            'nicnatdirect',                // Menu slug
            'nicnatdirect_main_page',    // Function
            'a',    // Icon
            56                            // Position
        );

        if (check_plugin_access()) {

            //1. Track order
            add_submenu_page(
                'nicnatdirect',
                'Track Orders',
                'Track Orders',
                'manage_options',
                'nicnatdirect_track_orders',
                'nicnatdirect_track_orders_page'
            );


            // 2. Shipping Methods
            add_submenu_page(
                'nicnatdirect',
                'Shipping Methods',
                'Shipping Methods',
                'manage_options',
                'nicnatdirect_shipping_methods',
                'nicnatdirect_shipping_page'
            );

            // 3. Products Missing Dimensions
            $missing_count = nicnatdirect_get_missing_dimensions_count();
            $menu_label = 'Products Missing Dimensions' . ($missing_count > 0 ? ' <span class="update-plugins count-' . $missing_count . '"><span class="plugin-count">' . $missing_count . '</span></span>' : '');
            add_submenu_page(
                'nicnatdirect',
                'Products Missing Dimensions',
                $menu_label,
                'manage_options',
                'nicnatdirect_missing_dimensions',
                'nicnatdirect_missing_dimensions_page'
            );


            // shipping rates
            add_submenu_page(
                'nicnatdirect',
                'Shipping Rates',
                'Shipping Rates',
                'manage_options',
                'nicnatdirect_shipping_rates',
                'nicnatdirect_shipping_rate_page'
            );
        }

        // 3. Your Profile
        add_submenu_page(
            'nicnatdirect',
            'Your Profile',
            'Your Profile',
            'manage_options',
            'nicnatdirect_profile',
            'nicnatdirect_profile_page'
        );

        // 4. Credentials Settings
        // add_submenu_page(
        // 	'nicnatdirect',
        // 	'Credentials Settings',
        // 	'Credentials Settings',
        // 	'manage_options',
        // 	'nicnatdirect_credentials',
        // 	'nicnatdirect_credentials_page'
        // );
    }




    add_action('admin_head', 'nicnatdirect_custom_menu_icon');

    function nicnatdirect_custom_menu_icon()
    {
        echo '
    <style>
        #adminmenu #toplevel_page_nicnatdirect div.wp-menu-image {
            background: url("https://api.menuyes.com/assets/images/truck-icon.png") no-repeat center center !important;
            background-size: 20px 20px !important;
        }
        #adminmenu #toplevel_page_nicnatdirect .wp-menu-image img {
            display: none;
        }
    </style>';
    }



    function nicnatdirect_shipping_rate_page()
    {
        $domain = site_url();
?>

        <div class="wrap">
            <div class="nicnat-wrapper">
                <div class="nicnat-container">
                    <h1 class="wp-heading-inline">Shipping <span style="color: #007cba;">Rates</span></h1>

                    <!-- Select Box -->
                    <div style="margin: 20px 0;">
                        <label for="shipping_country">Select Country </label>
                        <select id="shipping_country" class="regular-text">
                            <option value="">All</option>
                        </select>
                    </div>

                    <!-- Table -->
                    <div class="table-wrap">
                        <table id="shipping_rates_table" class="wp-list-table widefat fixed striped table-view-list">
                            <thead>
                                <tr>
                                    <th scope="col">ID</th>
                                    <th scope="col">Country (Zone)</th>
                                    <th scope="col">Weight (lbs)</th>
                                    <th scope="col">Shipping Rate</th>
                                </tr>
                            </thead>
                            <tbody></tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>

        <!-- DataTables CSS and JS -->
        <link rel="stylesheet" href="https://cdn.datatables.net/1.13.6/css/jquery.dataTables.min.css">
        <script src="https://code.jquery.com/jquery-3.7.1.min.js"></script>
        <script src="https://cdn.datatables.net/1.13.6/js/jquery.dataTables.min.js"></script>

        <script>
            jQuery(document).ready(function($) {
                let table = $('#shipping_rates_table').DataTable({
                    responsive: true,
                    pageLength: 20
                });

                let storedResponse = [];

                function load_rate() {
                    var nicnat_api_info = {
                        domain_name: "<?php echo esc_js($domain); ?>"
                    };

                    $.ajax({
                        url: 'https://nicnatdirect.com/global/api/get_country_shipping_rates.php',
                        method: 'POST',
                        contentType: 'application/json',
                        data: JSON.stringify({
                            domain_name: nicnat_api_info.domain_name
                        }),
                        success: function(response) {
                            if (response.status === 'success') {
                                storedResponse = response.data;


                                let select = $('#shipping_country');
                                select.find("option:gt(0)").remove();
                                table.clear().draw();

                                let addedOptions = new Set();
                                let rowId = 1;

                                storedResponse.forEach((entry) => {
                                    let countries = entry.countries;
                                    let rates = entry.shipping_rates;

                                    countries.forEach((country) => {
                                        let zone = country.zone_name;
                                        let countryText = `${country.country_name} (${zone})`;
                                        let countryValue = `${country.country_code}-${zone}`;

                                        if (!addedOptions.has(countryValue)) {
                                            select.append(`<option value="${countryValue}">${countryText}</option>`);
                                            addedOptions.add(countryValue);
                                        }

                                        rates.forEach((rate) => {
                                            if (parseInt(rate.zone_id) == zone.charCodeAt(0) - 64) { // A=1, B=2, etc.
                                                table.row.add([
                                                    rowId++,
                                                    countryText,
                                                    rate.weight,
                                                    `$${rate.rate}`
                                                ]);
                                            }
                                        });
                                    });
                                });

                                table.draw();
                            } else {
                                alert(response.message || 'Error loading data');
                            }
                        }
                    });
                }

                // Filter logic
                $('#shipping_country').on('change', function() {
                    let selectedZone = $(this).val();
                    let table = $('#shipping_rates_table').DataTable();
                    table.clear();
                    let rowId = 1;

                    storedResponse.forEach((entry) => {
                        let countries = entry.countries;
                        let rates = entry.shipping_rates;

                        countries.forEach((country) => {
                            let zone = country.zone_name;
                            let countryValue = `${country.country_code}-${zone}`;
                            let countryText = `${country.country_name} (${zone})`;

                            if (selectedZone === "" || countryValue === selectedZone) {
                                rates.forEach((rate) => {
                                    if (parseInt(rate.zone_id) == zone.charCodeAt(0) - 64) {
                                        table.row.add([
                                            rowId++,
                                            countryText,
                                            rate.weight,
                                            `$${rate.rate}`
                                        ]);
                                    }
                                });
                            }
                        });
                    });

                    table.draw();
                });

                load_rate();
            });
        </script>

    <?php
    }






    // Count how many products are missing any dimension
    function nicnatdirect_get_missing_dimensions_count()
    {
        global $wpdb;

        $query = "
        SELECT COUNT(*) FROM {$wpdb->posts} p
        LEFT JOIN {$wpdb->prefix}postmeta pm_weight ON p.ID = pm_weight.post_id AND pm_weight.meta_key = '_weight'
        LEFT JOIN {$wpdb->prefix}postmeta pm_height ON p.ID = pm_height.post_id AND pm_height.meta_key = '_length'
        LEFT JOIN {$wpdb->prefix}postmeta pm_width ON p.ID = pm_width.post_id AND pm_width.meta_key = '_width'
        LEFT JOIN {$wpdb->prefix}postmeta pm_length ON p.ID = pm_length.post_id AND pm_length.meta_key = '_height'
        WHERE p.post_type = 'product' 
        AND (
            pm_weight.meta_value IS NULL OR pm_height.meta_value IS NULL OR 
            pm_width.meta_value IS NULL OR pm_length.meta_value IS NULL
        )
    ";

        return (int) $wpdb->get_var($query);
    }


    function nicnatdirect_main_page()
    {
        // Get missing and total product counts (replace with your actual logic if needed)
        $missing_count = nicnatdirect_get_missing_dimensions_count(); // You already have this

    ?>
        <div class="wrap">
            <h1 class="wp-heading-inline">
                Welcome to <span style="color: #007cba;">NicnatDirect</span>
            </h1>
            <hr class="wp-header-end">

            <div style="display: flex; flex-wrap: wrap; gap: 20px; margin-top: 30px;">

                <!-- Card 1 -->
                <?php if (!check_plugin_access()) { ?>

                    <div style="flex: 1 1 300px; background: #fff; padding: 20px; border: 1px solid #ccd0d4; border-radius: 8px; box-shadow: 0 2px 4px rgba(0,0,0,0.05); margin-bottom: 20px;">
                        <h2 style="font-size: 20px;">🎯 Quick Setup</h2>
                        <p>Follow the steps below to access all features of NicnatDirect plugin:</p>

                        <ol style="padding-left: 20px; margin-bottom: 15px;">
                            <li>✅ Install the plugin</li>
                            <li>✅ Activate it</li>
                            <li>✅ Set up your profile</li>
                            <li>✅ On profile save, credentials will be emailed to access all plugins</li>
                        </ol>

                        <h3 style="font-size: 16px; margin-top: 20px;">📦 Product Requirements</h3>
                        <ul style="padding-left: 20px;">
                            <li>Each product must include:</li>
                            <li>➡️ Length</li>
                            <li>➡️ Width</li>
                            <li>➡️ Height</li>
                            <li>➡️ Weight</li>
                        </ul>

                        <a href="admin.php?page=nicnatdirect_profile" class="button button-primary" style="margin-top: 15px;">Start Setup</a>
                    </div>



                <?php } ?>


                <!-- Card 4: Product Dimensions -->
                <?php if (check_plugin_access()) { ?>
                    <?php if ($missing_count > 0) { ?>
                        <div style="flex: 1 1 300px; background: #fff; padding: 20px; border: 1px solid #ccd0d4; border-radius: 8px; box-shadow: 0 2px 4px rgba(0,0,0,0.05);">
                            <h2 style="font-size: 20px;">📏 Product Dimensions</h2>
                            <p><strong>All products have weight, height, width, and length.</strong></p>
                            <p><strong>Missing Dimensions:</strong> <?php echo $missing_count; ?></p>
                            <a href="admin.php?page=nicnatdirect_missing_dimensions" class="button">Fix Now</a>
                        </div>
                    <?php }
                    ?>



                    <?php
                    // Inside: if (check_plugin_access()) {
                    $orders = wc_get_orders([
                        'limit' => 5, // Change the number to show more or less
                        'orderby' => 'date',
                        'order' => 'DESC',
                    ]);

                    $domain = site_url();

                    if (!empty($orders)) {
                    ?>
                        <div style="flex: 1 1 100%; background: #fff; padding: 20px; border: 1px solid #ccd0d4; border-radius: 8px; box-shadow: 0 2px 4px rgba(0,0,0,0.05);">
                            <h2 style="font-size: 20px;">📦 Recent Orders</h2>
                            <table class="wp-list-table widefat fixed striped">
                                <thead>
                                    <tr>
                                        <th>Order #</th>
                                        <th>Date</th>
                                        <th>Status</th>
                                        <th>Track order</th>
                                        <th>Actions</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($orders as $order): ?>
                                        <tr>
                                            <td>#<?php echo esc_html($order->get_id()); ?></td>
                                            <td><?php echo esc_html($order->get_date_created()->date('Y-m-d H:i')); ?></td>
                                            <td><?php echo esc_html(wc_get_order_status_name($order->get_status())); ?></td>
                                            <td class="tracking-cell" data-order-id="<?php echo esc_attr($order->get_id()); ?>">Loading...</td>

                                            <td>
                                                <a href="<?php echo esc_url(admin_url('post.php?post=' . $order->get_id() . '&action=edit')); ?>" class="button">View</a>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>




                        <script>
                            jQuery(document).ready(function($) {
                                var nicnat_api_info = {
                                    domain_name: "<?php echo esc_js($domain); ?>"
                                };


                                $.ajax({
                                    url: 'https://nicnatdirect.com/global/api/get_tracking_ids.php',
                                    method: 'POST',
                                    contentType: 'application/json',
                                    data: JSON.stringify({
                                        domain_name: nicnat_api_info.domain_name
                                    }),
                                    success: function(response) {
                                        if (response.success && response.data) {

                                            //	console.log(response.data);
                                            $('.tracking-cell').each(function() {
                                                var orderId = $(this).data('order-id');
                                                var trackingUrl = response.data[orderId] || 'Not available';

                                                if (trackingUrl !== 'Not available') {
                                                    $(this).html('<a href="' + trackingUrl + '" target="_blank">Track</a>');
                                                } else {
                                                    $(this).text(trackingUrl);
                                                }
                                            });
                                        } else {
                                            $('.tracking-cell').text('Not available');
                                        }
                                    },
                                    error: function() {
                                        $('.tracking-cell').text('API Error');
                                    }
                                });

                            });
                        </script>






                <?php
                    } else {
                        echo '<div style="flex: 1 1 100%;"><p>No recent orders found.</p></div>';
                    }
                }
                ?>





            </div>
        </div>
    <?php
    }











    // // Shipping methods placeholder
    function nicnatdirect_shipping_page()
    {
        if (isset($_GET['page']) && $_GET['page'] === 'nicnatdirect_shipping_methods') {
            // WooCommerce settings URL
            wp_redirect(admin_url('admin.php?page=wc-settings&tab=shipping&section=wsef_dynamic_shipping'));
            exit;
        }
    }

    // Step 2: Callback function for displaying the products with missing dimensions
    function nicnatdirect_missing_dimensions_page()
    {
        global $wpdb;

        // Get the products with missing weight, height, width, or length
        $query = "
        SELECT p.ID, p.post_title, pm_weight.meta_value AS weight, 
               pm_height.meta_value AS height, pm_width.meta_value AS width, 
               pm_length.meta_value AS length
        FROM {$wpdb->posts} p
        LEFT JOIN {$wpdb->prefix}postmeta pm_weight ON p.ID = pm_weight.post_id AND pm_weight.meta_key = '_weight'
        LEFT JOIN {$wpdb->prefix}postmeta pm_height ON p.ID = pm_height.post_id AND pm_height.meta_key = '_length'
        LEFT JOIN {$wpdb->prefix}postmeta pm_width ON p.ID = pm_width.post_id AND pm_width.meta_key = '_width'
        LEFT JOIN {$wpdb->prefix}postmeta pm_length ON p.ID = pm_length.post_id AND pm_length.meta_key = '_height'
        WHERE p.post_type = 'product' 
        AND (
            pm_weight.meta_value IS NULL OR pm_height.meta_value IS NULL OR 
            pm_width.meta_value IS NULL OR pm_length.meta_value IS NULL
        )
        ORDER BY p.post_title;
    ";

        // Execute the query
        $products = $wpdb->get_results($query);

        // Step 3: Display the products in a table
    ?>
        <!-- <div class="wrap">
		<h1>Products Missing Dimensions</h1>
		<table class="widefat"> -->

        <div style="flex: 1 1 100%; background: #fff; padding: 20px; border: 1px solid #ccd0d4; border-radius: 8px; box-shadow: 0 2px 4px rgba(0,0,0,0.05); margin-top:20px; margin-right:20px;">
            <h2 style="font-size: 20px;">Products Missing Dimensions</h2>
            <table class="wp-list-table widefat fixed striped">
                <thead>
                    <tr>
                        <th>Product Name</th>
                        <th>Weight</th>
                        <th>Height</th>
                        <th>Width</th>
                        <th>Length</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php
                    if ($products) {
                        foreach ($products as $product) {
                            $edit_url = get_edit_post_link($product->ID); // URL for full edit page
                    ?>
                            <tr>
                                <td><?php echo esc_html($product->post_title); ?></td>
                                <td><?php echo (empty($product->weight) ? 'Missing' : esc_html($product->weight)); ?></td>
                                <td><?php echo (empty($product->height) ? 'Missing' : esc_html($product->height)); ?></td>
                                <td><?php echo (empty($product->width) ? 'Missing' : esc_html($product->width)); ?></td>
                                <td><?php echo (empty($product->length) ? 'Missing' : esc_html($product->length)); ?></td>
                                <td>
                                    <!-- Full Edit button -->
                                    <a href="<?php echo esc_url($edit_url); ?>" target="_blank">Edit</a>
                                </td>
                            </tr>
                    <?php
                        }
                    } else {
                        echo '<tr><td colspan="6">No products found with missing dimensions.</td></tr>';
                    }
                    ?>
                </tbody>
            </table>
        </div>


        <?php
    }













    function nicnatdirect_track_orders_page()
    {
        $domain = site_url();
        $per_page = 20;
        $paged = isset($_GET['paged']) ? intval($_GET['paged']) : 1;
        $offset = ($paged - 1) * $per_page;

        // Get total number of orders
        $args_for_count = [
            'orderby' => 'date',
            'order'   => 'DESC',
            'return'  => 'ids'
        ];
        $all_order_ids = wc_get_orders($args_for_count);
        $total_orders = count($all_order_ids);
        $total_pages = ceil($total_orders / $per_page);

        // Get paginated orders
        $orders = wc_get_orders([
            'orderby' => 'date',
            'order'   => 'DESC',
            'limit'   => $per_page,
            'offset'  => $offset,
        ]);

        if (!empty($orders)) {
        ?>

            <style>
                .page-numbers {
                    margin-right: 5px;
                    padding: 5px 10px;
                    color: #000;
                    border: 1px solid #ccc;
                }

                .page-numbers.current {
                    margin-right: 5px;
                    background: #8f8f8f;
                    padding: 5px 10px;
                    color: #fff;
                }
            </style>

            <div class="" style="flex: 1 1 100%; background: #fff; padding: 20px; border: 1px solid #ccd0d4; border-radius: 8px; box-shadow: 0 2px 4px rgba(0,0,0,0.05); margin-top:20px; margin-right:20px;">
                <h2 style="font-size: 20px;">📦 Orders</h2>
                <table class="wp-list-table widefat fixed striped">
                    <thead>
                        <tr>
                            <th>Order #</th>
                            <th>Date</th>
                            <th>Status</th>
                            <th>Track order</th>
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($orders as $order): ?>
                            <tr>
                                <td>#<?php echo esc_html($order->get_id()); ?></td>
                                <td><?php echo esc_html($order->get_date_created()->date('Y-m-d H:i')); ?></td>
                                <td><?php echo esc_html(wc_get_order_status_name($order->get_status())); ?></td>
                                <td class="tracking-cell" data-order-id="<?php echo esc_attr($order->get_id()); ?>">Loading...</td>
                                <td>
                                    <a href="<?php echo esc_url(admin_url('post.php?post=' . $order->get_id() . '&action=edit')); ?>" class="button">View</a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>

                <!-- Pagination -->
                <div style="margin-top: 20px;">
                    <?php if ($total_pages > 1): ?>
                        <div class="pagination">
                            <?php for ($i = 1; $i <= $total_pages; $i++): ?>
                                <a href="<?php echo esc_url(add_query_arg('paged', $i)); ?>" class="page-numbers <?php echo ($paged == $i) ? 'current' : ''; ?>" style="margin-right: 5px;"><?php echo $i; ?></a>
                            <?php endfor; ?>
                        </div>
                    <?php endif; ?>
                </div>
            </div>

            <script>
                jQuery(document).ready(function($) {
                    var nicnat_api_info = {
                        domain_name: "<?php echo esc_js($domain); ?>"
                    };

                    $.ajax({
                        url: 'https://nicnatdirect.com/global/api/get_tracking_ids.php',
                        method: 'POST',
                        contentType: 'application/json',
                        data: JSON.stringify({
                            domain_name: nicnat_api_info.domain_name
                        }),
                        success: function(response) {

                            if (response.success && response.data) {
                                $('.tracking-cell').each(function() {
                                    var orderId = $(this).data('order-id');
                                    var trackingUrl = response.data[orderId] || 'Not available';

                                    if (trackingUrl !== 'Not available') {
                                        $(this).html('<a href="' + trackingUrl + '" target="_blank">Track</a>');
                                    } else {
                                        $(this).text(trackingUrl);
                                    }
                                });
                            } else {
                                $('.tracking-cell').text('Not available');
                            }
                        },
                        error: function() {
                            $('.tracking-cell').text('API Error');
                        }
                    });
                });
            </script>
        <?php
        } else {
            echo '<div style="flex: 1 1 100%;"><p>No orders found.</p></div>';
        }
    }














    // Credentials page with form
    function nicnatdirect_credentials_page()
    {

        $current_user = wp_get_current_user();

        $email_id = $current_user->user_email;
        $domain = site_url(); // Domain name


        ?>
        <div class="wrap">
            <h2>API Credentials</h2>
            <form id="nicnat-credentials-form">
                <input type="hidden" name="domain_name" value="<?php echo esc_attr($domain); ?>">
                <input type="hidden" name="email_id" value="<?php echo esc_attr($email_id); ?>">

                <table class="form-table">


                    <tr>
                        <th><label for="user_key">API Key</label></th>
                        <td><input name="user_key" type="text" id="user_key" class="regular-text" /></td>
                    </tr>

                    <tr>
                        <th><label for="user_password">Password</label></th>
                        <td><input name="user_password" type="password" id="user_password" class="regular-text" /></td>
                    </tr>
                </table>

                <p>
                    <button type="submit" class="button button-primary">Save Credentials</button>
                </p>
                <div id="nicnat-cred-response"></div>
            </form>
        </div>

        <script>
            jQuery(document).ready(function($) {

                var nicnat_api_info = {
                    domain_name: "<?php echo esc_js($domain); ?>"
                };

                // Fetch credentials from external API
                $.ajax({
                    url: 'https://nicnatdirect.com/global/api/get_credentials.php',
                    method: 'POST',
                    contentType: 'application/json',
                    data: JSON.stringify({
                        domain_name: nicnat_api_info.domain_name
                    }),
                    success: function(response) {
                        if (response.success && response.data) {
                            const data = response.data;
                            $('#user_password').val(data.user_password || '');
                            $('#user_key').val(data.user_key || '');
                        }
                    }
                });

                // Save credentials to external API
                $('#nicnat-credentials-form').on('submit', function(e) {
                    e.preventDefault();

                    var formData = $(this).serializeArray();
                    var data = {};
                    $.each(formData, function(i, field) {
                        data[field.name] = field.value;
                    });

                    $.ajax({
                        url: 'https://nicnatdirect.com/global/api/check_credentials.php',
                        method: 'POST',
                        contentType: 'application/json',
                        data: JSON.stringify(data),
                        success: function(response) {
                            let msg = response.message || 'Credentials saved successfully.';
                            $('#nicnat-cred-response').html(`<div class="updated"><p>${msg}</p></div>`);
                            location.reload();
                        },
                        error: function(xhr) {
                            let msg = 'Something went wrong. Please try again.';
                            if (xhr.responseJSON && xhr.responseJSON.message) {
                                msg = xhr.responseJSON.message;
                            }
                            $('#nicnat-cred-response').html(`<div class="error"><p>${msg}</p></div>`);
                        }
                    });
                });
            });
        </script>

    <?php
    }










    // Profile page with form
    function nicnatdirect_profile_page()
    {

        $current_user = wp_get_current_user();

        $email_id = $current_user->user_email;
        $domain = site_url(); // Domain name


        // Get WooCommerce countries or fallback to a hardcoded list
        if (function_exists('WC')) {
            $countries = WC()->countries->get_countries();
        } else {
            $countries = array(
                'NA' => 'No Countries Found'
            );
        }


    ?>


        <!-- Select2 CSS -->
        <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />

        <!-- Select2 JS -->
        <script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>

        <script>
            jQuery(document).ready(function($) {
                $('#country').select2({
                    placeholder: 'Select a Country',
                    allowClear: true
                });
            });
        </script>

        <script>
            jQuery(document).ready(function($) {
                $('#pre_shipping_countries').select2({
                    placeholder: "Select preferred countries",
                    allowClear: true
                });
            });
        </script>



        <div class="wrap">
            <div class="nicnat-wrapper">
                <div class="nicnat-container">
                    <h2 class="nicnat-heading">Your Profile</h2>
                    <form id="nicnat-profile-form" class="nicnat-form">
                        <input type="hidden" name="domain_name" value="<?php echo esc_attr($domain); ?>">
                        <input type="hidden" name="wp_email_id" value="<?php echo esc_attr($email_id); ?>">

                        <div class="nicnat-grid">
                            <div class="nicnat-form-group">
                                <label for="company_name">Company Name</label>
                                <input type="text" name="company_name" id="company_name" />
                            </div>
                            <div class="nicnat-form-group">
                                <label for="business_runing_year">Business in Years</label>
                                <input type="text" name="business_runing_year" id="business_runing_year" />
                            </div>
                            <div class="nicnat-form-group">
                                <label for="full_name">Full Name</label>
                                <input type="text" name="full_name" id="full_name" required />
                            </div>
                            <div class="nicnat-form-group">
                                <label for="email_id">Email ID</label>
                                <input type="email" name="email_id" id="email_id" required />
                            </div>
                            <div class="nicnat-form-group">
                                <label for="phone_no">Phone Number</label>
                                <input type="text" name="phone_no" id="phone_no" />
                            </div>
                            <div class="nicnat-form-group">
                                <label for="address1">Address 1</label>
                                <input type="text" name="address1" id="address1" required />
                            </div>
                            <div class="nicnat-form-group">
                                <label for="address2">Address 2</label>
                                <input type="text" name="address2" id="address2" />
                            </div>
                            <div class="nicnat-form-group">
                                <label for="city">City</label>
                                <input type="text" name="city" id="city" />
                            </div>

                            <div class="nicnat-form-group">
                                <label for="state">State</label>
                                <input type="text" name="state" id="state" />
                            </div>
                            <div class="nicnat-form-group">
                                <label for="country">Country</label>
                                <select name="country" id="country" style="width: 100%" required>
                                    <option value="">Select a Country</option>
                                    <?php foreach ($countries as $code => $name): ?>
                                        <option value="<?php echo esc_attr($code); ?>"><?php echo esc_html($name); ?></option>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div class="nicnat-form-group">
                                <label for="zip_code">Zip Code</label>
                                <input type="text" name="zip_code" id="zip_code" />
                            </div>


                            <div class="nicnat-form-group">
                                <label for="pre_shipping_countries">Shipping Countries</label>
                                <select name="pre_shipping_countries[]" id="pre_shipping_countries" multiple style="width: 100%;">
                                    <?php
                                    $selected_countries = isset($data['pre_shipping_countries']) ? explode(',', $data['pre_shipping_countries']) : [];
                                    foreach ($countries as $code => $name): ?>
                                        <option value="<?php echo esc_attr($code); ?>"
                                            <?php echo in_array($code, $selected_countries) ? 'selected' : ''; ?>>
                                            <?php echo esc_html($name); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                                <small>You can search and select multiple countries.</small>
                            </div>


                            <div class="nicnat-form-group full-width" style="grid-column: span 4;">
                                <label for="uninstall_setting">Uninstall Settings</label>
                                <p>When you delete the plugin, should your profile be deleted permanently or temporarily?</p>
                                <div style="display: flex;align-items: center;gap:4px;">
                                    <input type="radio" id="delete_permanently" name="delete_permanently" value="1" required>
                                    <label for="delete_permanently">Permanently</label>
                                    <input type="radio" id="delete_temporarily" name="delete_permanently" value="0">
                                    <label for="delete_temporarily">Temporarily</label>
                                </div>
                            </div>




                            <div class="nicnat-form-group full-width">
                                <label class="checkbox-label">
                                    <input type="checkbox" name="terms" id="terms" required>
                                    <span class="checkbox-custom"></span>
                                    I agree to the terms and conditions.
                                </label>
                            </div>

                        </div>

                        <div class="nicnat-submit">
                            <button type="submit" class="nicnat-btn nicnat-btn-primary">Save Details</button>
                        </div>

                        <div id="nicnat-response"></div>
                    </form>
                </div>
            </div>
        </div>


        <script>
            jQuery(document).ready(function($) {

                var nicnat_profile_info = {
                    domain_name: "<?php echo esc_js($domain); ?>"
                };

                function load_profile() {

                    $.ajax({
                        url: 'https://nicnatdirect.com/global/api/get_profile.php',
                        method: 'POST',
                        contentType: 'application/json',
                        data: JSON.stringify({
                            domain_name: nicnat_profile_info.domain_name
                        }),
                        success: function(response) {
                            if (response.success && response.data) {
                                const data = response.data;

                                // Fill form inputs
                                $('#full_name').val(data.full_name || '');
                                $('#phone_no').val(data.phone_no || '');
                                $('#address1').val(data.address1 || '');
                                $('#address2').val(data.address2 || '');
                                $('#city').val(data.city || '');
                                $('#state').val(data.state || '');
                                $('#country').val(data.country || '');
                                $("#email_id").val(data.email_id || '');

                                // if (data.pre_shipping_countries) {
                                // 	const selectedCountries = data.pre_shipping_countries.split(',').map(item => item.trim());
                                // 	$('#pre_shipping_countries').val(selectedCountries);
                                // }
                                if (data.country) {
                                    $('#country').val(data.country).trigger('change'); // Select the country dynamically
                                }

                                if (data.pre_shipping_countries) {
                                    const selectedCountries = data.pre_shipping_countries.split(',').map(item => item.trim());
                                    $('#pre_shipping_countries').val(selectedCountries).trigger('change'); // Trigger the change event to update Select2
                                }

                                $('#zip_code').val(data.zip_code || '');
                                $('#company_name').val(data.company_name || '');
                                $('#business_runing_year').val(data.business_runing_year || '');
                                // $('#pre_shipping_countries').val(data.pre_shipping_countries || '');
                                $('#terms').attr("checked", true);


                                if (data.delete_permanently == 1) {
                                    $('#delete_permanently').prop('checked', true);
                                } else {
                                    $('#delete_temporarily').prop('checked', true);
                                }

                            }
                        }
                    });


                }

                load_profile();


                $('#nicnat-profile-form').on('submit', function(e) {
                    e.preventDefault();

                    var formData = $(this).serializeArray();
                    var data = {};

                    // Convert formData to object
                    $.each(formData, function(i, field) {
                        data[field.name] = field.value;
                    });

                    // Handle multi-select countries dropdown manually
                    data['pre_shipping_countries'] = $('#pre_shipping_countries').val() ? $('#pre_shipping_countries').val().join(',') : '';

                    $.ajax({
                        url: 'https://nicnatdirect.com/global/api/save_profile.php',
                        method: 'POST',
                        contentType: 'application/json',
                        data: JSON.stringify(data),
                        success: function(response) {
                            let msg = response.message || 'Profile saved successfully.';
                            $('#nicnat-response').html(`<div class="updated"><p>${msg}</p></div>`);

                            load_profile();
                            if (response.time == 1) {
                                setTimeout(function() {
                                    window.location.href = "/wp-admin/admin.php?page=nicnatdirect";
                                }, 2000);
                            }
                        },
                        error: function(xhr) {
                            let msg = 'Something went wrong. Please try again.';
                            if (xhr.responseJSON && xhr.responseJSON.message) {
                                msg = xhr.responseJSON.message;
                            }
                            $('#nicnat-response').html(`<div class="error"><p>${msg}</p></div>`);
                        }
                    });
                });

            });
        </script>

<?php
    }





    // ===============================================================================================================
    // ================================== WordPress Admin Panel Sidebar Menu =========================================
    // ===============================================================================================================

} else {
    // Admin menu: Always show "Nicnat Direct"
    add_action('admin_menu', 'nicnat_direct_admin_menu');
    function nicnat_direct_admin_menu()
    {
        add_menu_page(
            'Nicnat Direct',              // Page title
            'Nicnat Direct',              // Menu title
            'manage_options',             // Capability
            'nicnat-direct-dashboard',    // Menu slug
            'nicnat_direct_admin_page',   // Callback function
            'dashicons-admin-generic',    // Icon
            56                            // Position
        );
    }

    // Admin page content
    function nicnat_direct_admin_page()
    {
        echo '<div class="wrap"><h1>Nicnat Direct</h1>';

        $access_data = check_user_access();

        if (!$access_data['access']) {
            $reason = isset($access_data['reason']) ? $access_data['reason'] : 'Access denied.';
            echo '<div class="notice notice-error" style="padding:15px; margin-top:15px;"><p><strong>Access Blocked</strong> <br /><strong>Reason:<strong> ' . esc_html($reason) . '</p></div>';
        } else {
            echo '<p>Welcome! Plugin access is active.</p>';
            // Show actual plugin settings or content here
        }

        echo '</div>';
    }
}











// ===============================================================================================================
// ================================== active, deactivated, uninstalled =========================================
// ===============================================================================================================



function call_plugin_status_api($status)
{
    $response = wp_remote_post('https://nicnatdirect.com/global/api/plugin_status.php', [
        'headers' => ['Content-Type' => 'application/json'],
        'body'    => json_encode([
            'domain_name'   => get_site_url(),
            'plugin_status' => $status, // 1 = active, 0 = deactivated, 2 = uninstalled
        ]),
    ]);
}

// On activation
register_activation_hook(__FILE__, function () {
    call_plugin_status_api(1);
});

// On deactivation
register_deactivation_hook(__FILE__, function () {
    call_plugin_status_api(0);
});

// On uninstall
register_uninstall_hook(__FILE__, 'your_plugin_uninstall');
function your_plugin_uninstall()
{
    call_plugin_status_api(2);
}




// ===============================================================================================================
// ================================== active, deactivated, uninstalled =========================================
// ===============================================================================================================
